@@ -1,10 +1,10 @@
 # coding: utf-8
 
-truthy = frozenset(('t', 'true', 'y', 'yes', 'on', '1'))
+truthy = frozenset(("t", "true", "y", "yes", "on", "1"))
 
 
 def asbool(s):
-    """ Return the boolean value ``True`` if the case-lowered value of string
+    """Return the boolean value ``True`` if the case-lowered value of string
     input ``s`` is a :term:`truthy string`. If ``s`` is already one of the
     boolean values ``True`` or ``False``, return it."""
     if s is None:
